@@ -49,6 +49,8 @@ $attributemap = array(
     'urn:oid:1.2.840.113549.1.9.1'       => 'email',
     'urn:oid:1.2.752.194.10.2.2'         => 'sisSchoolGrade',
     'urn:oid:1.2.752.194.10.2.1'         => 'sisLegalGuardianFor',
+    'urn:oid:1.2.752.194.10.3'           => 'sisOrgDepartment',
+    'urn:oid:1.2.752.194.10.2.4'         => 'sisSchoolUnitCode',
     'urn:oid:1.3.6.1.4.1.2428.90.1.1'    => 'norEduOrgUniqueNumber',
     'urn:oid:1.3.6.1.4.1.2428.90.1.11'   => 'norEduOrgSchemaVersion',
     'urn:oid:1.3.6.1.4.1.2428.90.1.12'   => 'norEduOrgNIN',
@@ -60,10 +62,13 @@ $attributemap = array(
     'urn:oid:1.3.6.1.4.1.2428.90.1.7'    => 'norEduOrgUniqueIdentifier',
     'urn:oid:1.3.6.1.4.1.2428.90.1.8'    => 'norEduOrgUnitUniqueIdentifier',
     'urn:oid:1.3.6.1.4.1.2428.90.1.9'    => 'federationFeideSchemaVersion',
+    'urn:oid:1.3.6.1.4.1.24552.500.1.1.1.13' => 'sshPublicKey',
     'urn:oid:1.3.6.1.4.1.250.1.57'       => 'labeledURI',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.1'   => 'eduPersonAffiliation',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.11'  => 'eduPersonAssurance',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.10'  => 'eduPersonTargetedID',
+    'urn:oid:1.3.6.1.4.1.5923.1.1.1.13'  => 'eduPersonUniqueId',
+    'urn:oid:1.3.6.1.4.1.5923.1.1.1.16'  => 'eduPersonOrcid',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.2'   => 'eduPersonNickname',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.3'   => 'eduPersonOrgDN',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.4'   => 'eduPersonOrgUnitDN',
