@@ -49,6 +49,8 @@ $attributemap = array(
     'urn:oid:1.2.840.113549.1.9.1'       => 'urn:mace:dir:attribute-def:email',
     'urn:oid:1.2.752.194.10.2.2'         => 'urn:mace:dir:attribute-def:sisSchoolGrade',
     'urn:oid:1.2.752.194.10.2.1'         => 'urn:mace:dir:attribute-def:sisLegalGuardianFor',
+    'urn:oid:1.2.752.194.10.3'           => 'urn:mace:dir:attribute-def:sisOrgDepartment',
+    'urn:oid:1.2.752.194.10.2.4'         => 'urn:mace:dir:attribute-def:sisSchoolUnitCode',
     'urn:oid:1.3.6.1.4.1.2428.90.1.1'    => 'urn:mace:dir:attribute-def:norEduOrgUniqueNumber',
     'urn:oid:1.3.6.1.4.1.2428.90.1.11'   => 'urn:mace:dir:attribute-def:norEduOrgSchemaVersion',
     'urn:oid:1.3.6.1.4.1.2428.90.1.12'   => 'urn:mace:dir:attribute-def:norEduOrgNIN',
@@ -64,6 +66,7 @@ $attributemap = array(
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.1'   => 'urn:mace:dir:attribute-def:eduPersonAffiliation',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.11'  => 'urn:mace:dir:attribute-def:eduPersonAssurance',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.10'  => 'urn:mace:dir:attribute-def:eduPersonTargetedID',
+    'urn:oid:1.3.6.1.4.1.5923.1.1.1.13'  => 'urn:mace:dir:attribute-def:eduPersonUniqueId',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.2'   => 'urn:mace:dir:attribute-def:eduPersonNickname',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.3'   => 'urn:mace:dir:attribute-def:eduPersonOrgDN',
     'urn:oid:1.3.6.1.4.1.5923.1.1.1.4'   => 'urn:mace:dir:attribute-def:eduPersonOrgUnitDN',
