@@ -54,6 +54,7 @@ $attributemap = array(
     'urn:mace:dir:attribute-def:eduPersonPrincipalName'           => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.6',
     'urn:mace:dir:attribute-def:eduPersonScopedAffiliation'       => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.9',
     'urn:mace:dir:attribute-def:eduPersonTargetedID'              => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.10',
+    'urn:mace:dir:attribute-def:eduPersonUniqueId'                => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.13',
     'urn:mace:dir:attribute-def:email'                            => 'urn:oid:1.2.840.113549.1.9.1',
     'urn:mace:dir:attribute-def:emailAddress'                     => 'urn:oid:1.2.840.113549.1.9.1',
     'urn:mace:dir:attribute-def:employeeNumber'                   => 'urn:oid:2.16.840.1.113730.3.1.3',
@@ -136,6 +137,8 @@ $attributemap = array(
     'urn:mace:dir:attribute-def:singleLevelQuality'               => 'urn:oid:0.9.2342.19200300.100.1.50',
     'urn:mace:dir:attribute-def:sisSchoolGrade'                   => 'urn:oid:1.2.752.194.10.2.2',
     'urn:mace:dir:attribute-def:sisLegalGuardianFor'              => 'urn:oid:1.2.752.194.10.2.1',
+    'urn:mace:dir:attribute-def:sisOrgDepartment'                 => 'urn:oid:1.2.752.194.10.3',
+    'urn:mace:dir:attribute-def:sisSchoolUnitCode'                => 'urn:oid:1.2.752.194.10.2.4',
     'urn:mace:dir:attribute-def:sn'                               => 'urn:oid:2.5.4.4',
     'urn:mace:dir:attribute-def:st'                               => 'urn:oid:2.5.4.8',
     'urn:mace:dir:attribute-def:stateOrProvinceName'              => 'urn:oid:2.5.4.8',
