@@ -3,8 +3,8 @@
 /**
  * Exception which will show a 404 Not Found error page.
  *
- * This exception can be thrown from within an module page handler. The user will then be
- * shown a 404 Not Found error page.
+ * This exception can be thrown from within a module page handler. The user will then be shown a 404 Not Found error
+ * page.
  *
  * @author Olav Morken, UNINETT AS.
  * @package SimpleSAMLphp
@@ -31,8 +31,10 @@ class SimpleSAML_Error_NotFound extends SimpleSAML_Error_Error {
 
 		if($reason === NULL) {
 			parent::__construct(array('NOTFOUND', '%URL%' => $url));
+			$this->message = "The requested page '$url' could not be found.";
 		} else {
 			parent::__construct(array('NOTFOUNDREASON', '%URL%' => $url, '%REASON%' => $reason));
+			$this->message = "The requested page '$url' could not be found. ".$reason;
 		}
 
 		$this->reason = $reason;
@@ -49,4 +51,18 @@ class SimpleSAML_Error_NotFound extends SimpleSAML_Error_Error {
 		return $this->reason;
 	}
 
+
+	/**
+	 * NotFound exceptions don't need to display a backtrace, as they are very simple and the trace is usually trivial,
+	 * so just log the message without any backtrace at all.
+	 *
+	 * @param bool $anonymize Whether to anonymize the trace or not.
+	 *
+	 * @return array
+	 */
+	public function format($anonymize = false) {
+		return array(
+			$this->getClass().': '.$this->getMessage(),
+		);
+	}
 }
