@@ -6,13 +6,16 @@
  *
  * @package SimpleSAMLphp
  */
-class SimpleSAML_SessionHandlerStore extends SimpleSAML_SessionHandlerCookie
+
+namespace SimpleSAML;
+
+class SessionHandlerStore extends SessionHandlerCookie
 {
 
     /**
      * The data store we save the session to.
      *
-     * @var SimpleSAML_Store
+     * @var \SimpleSAML\Store
      */
     private $store;
 
@@ -20,9 +23,9 @@ class SimpleSAML_SessionHandlerStore extends SimpleSAML_SessionHandlerCookie
     /**
      * Initialize the session.
      *
-     * @param SimpleSAML_Store $store The store to use.
+     * @param \SimpleSAML\Store $store The store to use.
      */
-    protected function __construct(SimpleSAML_Store $store)
+    protected function __construct(Store $store)
     {
         parent::__construct();
 
@@ -35,7 +38,7 @@ class SimpleSAML_SessionHandlerStore extends SimpleSAML_SessionHandlerCookie
      *
      * @param string|null $sessionId The ID of the session we should load, or null to use the default.
      *
-     * @return SimpleSAML_Session|null The session object, or null if it doesn't exist.
+     * @return \SimpleSAML_Session|null The session object, or null if it doesn't exist.
      */
     public function loadSession($sessionId = null)
     {
@@ -62,18 +65,16 @@ class SimpleSAML_SessionHandlerStore extends SimpleSAML_SessionHandlerCookie
     /**
      * Save a session to the data store.
      *
-     * @param SimpleSAML_Session $session The session object we should save.
+     * @param \SimpleSAML_Session $session The session object we should save.
      */
-    public function saveSession(SimpleSAML_Session $session)
+    public function saveSession(\SimpleSAML_Session $session)
     {
-
         $sessionId = $session->getSessionId();
 
-        $config = SimpleSAML_Configuration::getInstance();
+        $config = \SimpleSAML_Configuration::getInstance();
         $sessionDuration = $config->getInteger('session.duration', 8 * 60 * 60);
         $expire = time() + $sessionDuration;
 
         $this->store->set('session', $sessionId, $session, $expire);
     }
-
 }
