@@ -27,6 +27,12 @@ class Metadata
 
 
     /**
+     * Valid options for the ContactPerson element
+     *
+     * The 'attributes' option isn't defined in section 2.3.2.2 of the OASIS document, but
+     * it is required to allow additons to the main contact person element for trust
+     * frameworks.
+     *
      * @var array The valid configuration options for a contact configuration array.
      * @see "Metadata for the OASIS Security Assertion Markup Language (SAML) V2.0", section 2.3.2.2.
      */
@@ -37,6 +43,7 @@ class Metadata
         'surName',
         'telephoneNumber',
         'company',
+        'attributes',
     );
 
 
@@ -108,6 +115,16 @@ class Metadata
             throw new \InvalidArgumentException('"contactType" is mandatory and must be one of '.$types.".");
         }
 
+        // check attributes is an associative array
+        if (isset($contact['attributes'])) {
+            if (empty($contact['attributes']) 
+                || !is_array($contact['attributes']) 
+                || count(array_filter(array_keys($contact['attributes']), 'is_string')) === 0
+            ) {
+                throw new \InvalidArgumentException('"attributes" must be an array and cannot be empty.');
+            }
+        }
+
         // try to fill in givenName and surName from name
         if (isset($contact['name']) && !isset($contact['givenName']) && !isset($contact['surName'])) {
             // first check if it's comma separated
@@ -207,7 +224,7 @@ class Metadata
         $firstAllowed = null;
 
         // look through the endpoint list for acceptable endpoints
-        foreach ($endpoints as $i => $ep) {
+        foreach ($endpoints as $ep) {
             if ($bindings !== null && !in_array($ep['Binding'], $bindings, true)) {
                 // unsupported binding, skip it
                 continue;
@@ -255,13 +272,11 @@ class Metadata
      *
      * @return boolean True if the entity should be hidden, false otherwise.
      */
-    public static function isHiddenFromDiscovery($metadata)
+    public static function isHiddenFromDiscovery(array $metadata)
     {
-        if (array_key_exists(self::$ENTITY_CATEGORY, $metadata['EntityAttributes'])) {
-            if (in_array(self::$HIDE_FROM_DISCOVERY, $metadata['EntityAttributes'][self::$ENTITY_CATEGORY])) {
-                return true;
-            }
-        }
-        return false;
+        \SimpleSAML\Logger::maskErrors(E_ALL);
+        $hidden = in_array(self::$HIDE_FROM_DISCOVERY, $metadata['EntityAttributes'][self::$ENTITY_CATEGORY], true);
+        \SimpleSAML\Logger::popErrorMask();
+        return $hidden === true;
     }
 }
