@@ -1,9 +1,9 @@
 <?php
+
 namespace SimpleSAML\Utils;
 
-
 /**
- * A class for cryptography-related functions
+ * A class for cryptography-related functions.
  *
  * @package SimpleSAMLphp
  */
@@ -17,14 +17,21 @@ class Crypto
      * @param string $secret The secret to use to decrypt the data.
      *
      * @return string The decrypted data.
-     * @htorws \InvalidArgumentException If $ciphertext is not a string.
+     * @throws \InvalidArgumentException If $ciphertext is not a string.
      * @throws \SimpleSAML_Error_Exception If the openssl module is not loaded.
      *
      * @see \SimpleSAML\Utils\Crypto::aesDecrypt()
      */
     private static function _aesDecrypt($ciphertext, $secret)
     {
-        if (!is_string($ciphertext) || mb_strlen($ciphertext, '8bit') < 48) {
+        if (!is_string($ciphertext)) {
+            throw new \InvalidArgumentException(
+                'Input parameter "$ciphertext" must be a string with more than 48 characters.'
+            );
+        }
+        /** @var int $len */
+        $len = mb_strlen($ciphertext, '8bit');
+        if ($len < 48) {
             throw new \InvalidArgumentException(
                 'Input parameter "$ciphertext" must be a string with more than 48 characters.'
             );
@@ -38,7 +45,7 @@ class Crypto
 
         $hmac = mb_substr($ciphertext, 0, 32, '8bit');
         $iv   = mb_substr($ciphertext, 32, 16, '8bit');
-        $msg  = mb_substr($ciphertext, 48, mb_strlen($ciphertext, '8bit') - 48, '8bit');
+        $msg  = mb_substr($ciphertext, 48, $len - 48, '8bit');
 
         // authenticate the ciphertext
         if (self::secureCompare(hash_hmac('sha256', $iv.$msg, substr($key, 64, 64), true), $hmac)) {
@@ -46,7 +53,7 @@ class Crypto
                 $msg,
                 'AES-256-CBC',
                 substr($key, 0, 64),
-                defined('OPENSSL_RAW_DATA') ? OPENSSL_RAW_DATA : true,
+                defined('OPENSSL_RAW_DATA') ? OPENSSL_RAW_DATA : 1,
                 $iv
             );
 
@@ -65,7 +72,7 @@ class Crypto
      * @param string $ciphertext The HMAC of the encrypted data, the IV used and the encrypted data, concatenated.
      *
      * @return string The decrypted data.
-     * @htorws \InvalidArgumentException If $ciphertext is not a string.
+     * @throws \InvalidArgumentException If $ciphertext is not a string.
      * @throws \SimpleSAML_Error_Exception If the openssl module is not loaded.
      *
      * @author Andreas Solberg, UNINETT AS <andreas.solberg@uninett.no>
@@ -106,11 +113,12 @@ class Crypto
         $iv = openssl_random_pseudo_bytes(16);
 
         // encrypt the message
-        $ciphertext = $iv.openssl_encrypt(
+        /** @var string|false $ciphertext */
+        $ciphertext = openssl_encrypt(
             $data,
             'AES-256-CBC',
             substr($key, 0, 64),
-            defined('OPENSSL_RAW_DATA') ? OPENSSL_RAW_DATA : true,
+            defined('OPENSSL_RAW_DATA') ? OPENSSL_RAW_DATA : 1,
             $iv
         );
 
@@ -119,7 +127,7 @@ class Crypto
         }
 
         // return the ciphertext with proper authentication
-        return hash_hmac('sha256', $ciphertext, substr($key, 64, 64), true).$ciphertext;
+        return hash_hmac('sha256', $iv.$ciphertext, substr($key, 64, 64), true).$iv.$ciphertext;
     }
 
 
@@ -141,6 +149,22 @@ class Crypto
     }
 
 
+    /**
+     * Convert data from DER to PEM encoding.
+     *
+     * @param string $der Data encoded in DER format.
+     * @param string $type The type of data we are encoding, as expressed by the PEM header. Defaults to "CERTIFICATE".
+     * @return string The same data encoded in PEM format.
+     * @see RFC7648 for known types and PEM format specifics.
+     */
+    public static function der2pem($der, $type = 'CERTIFICATE')
+    {
+        return "-----BEGIN ".$type."-----\n".
+               chunk_split(base64_encode($der), 64, "\n").
+               "-----END ".$type."-----\n";
+    }
+
+
     /**
      * Load a private key from metadata.
      *
@@ -157,6 +181,8 @@ class Crypto
      * missing key will cause an exception. Defaults to false.
      * @param string                    $prefix The prefix which should be used when reading from the metadata
      * array. Defaults to ''.
+     * @param bool                      $full_path Whether the filename found in the configuration contains the
+     * full path to the private key or not. Default to false.
      *
      * @return array|NULL Extracted private key, or NULL if no private key is present.
      * @throws \InvalidArgumentException If $required is not boolean or $prefix is not a string.
@@ -166,9 +192,9 @@ class Crypto
      * @author Andreas Solberg, UNINETT AS <andreas.solberg@uninett.no>
      * @author Olav Morken, UNINETT AS <olav.morken@uninett.no>
      */
-    public static function loadPrivateKey(\SimpleSAML_Configuration $metadata, $required = false, $prefix = '')
+    public static function loadPrivateKey(\SimpleSAML_Configuration $metadata, $required = false, $prefix = '', $full_path = false)
     {
-        if (!is_bool($required) || !is_string($prefix)) {
+        if (!is_bool($required) || !is_string($prefix) || !is_bool($full_path)) {
             throw new \InvalidArgumentException('Invalid input parameters.');
         }
 
@@ -182,7 +208,10 @@ class Crypto
             }
         }
 
-        $file = Config::getCertPath($file);
+        if (!$full_path) {
+            $file = Config::getCertPath($file);
+        }
+
         $data = @file_get_contents($file);
         if ($data === false) {
             throw new \SimpleSAML_Error_Exception('Unable to load private key from file "'.$file.'"');
@@ -209,12 +238,13 @@ class Crypto
      * - 'certData': The certificate as a base64-encoded string.
      * - 'certificate': A file with a certificate or public key in PEM-format.
      * - 'certFingerprint': The fingerprint of the certificate. Can be a single fingerprint, or an array of multiple
-     * valid fingerprints.
+     * valid fingerprints. (deprecated)
      *
      * This function will return an array with these elements:
      * - 'PEM': The public key/certificate in PEM-encoding.
      * - 'certData': The certificate data, base64 encoded, on a single line. (Only present if this is a certificate.)
-     * - 'certFingerprint': Array of valid certificate fingerprints. (Only present if this is a certificate.)
+     * - 'certFingerprint': Array of valid certificate fingerprints. (Deprecated. Only present if this is a
+     *   certificate.)
      *
      * @param \SimpleSAML_Configuration $metadata The metadata.
      * @param bool                      $required Whether the private key is required. If this is TRUE, a missing key
@@ -270,8 +300,10 @@ class Crypto
                 $fp = strtolower(str_replace(':', '', $fp));
             }
 
-            // We can't build a full certificate from a fingerprint, and may as well return an array with only the
-            //fingerprint(s) immediately.
+            /*
+             * We can't build a full certificate from a fingerprint, and may as well return an array with only the
+             * fingerprint(s) immediately.
+             */
             return array('certFingerprint' => $fps);
         }
 
@@ -284,6 +316,35 @@ class Crypto
     }
 
 
+    /**
+     * Convert from PEM to DER encoding.
+     *
+     * @param string $pem Data encoded in PEM format.
+     * @return string The same data encoded in DER format.
+     * @throws \InvalidArgumentException If $pem is not encoded in PEM format.
+     * @see RFC7648 for PEM format specifics.
+     */
+    public static function pem2der($pem)
+    {
+        $pem   = trim($pem);
+        $begin = "-----BEGIN ";
+        $end   = "-----END ";
+        $lines = explode("\n", $pem);
+        $last  = count($lines) - 1;
+
+        if (strpos($lines[0], $begin) !== 0) {
+            throw new \InvalidArgumentException("pem2der: input is not encoded in PEM format.");
+        }
+        unset($lines[0]);
+        if (strpos($lines[$last], $end) !== 0) {
+            throw new \InvalidArgumentException("pem2der: input is not encoded in PEM format.");
+        }
+        unset($lines[$last]);
+
+        return base64_decode(implode($lines));
+    }
+
+
     /**
      * This function hashes a password with a given algorithm.
      *
@@ -308,7 +369,7 @@ class Crypto
         }
 
         // hash w/o salt
-        if (in_array(strtolower($algorithm), hash_algos())) {
+        if (in_array(strtolower($algorithm), hash_algos(), true)) {
             $alg_str = '{'.str_replace('SHA1', 'SHA', $algorithm).'}'; // LDAP compatibility
             $hash = hash(strtolower($algorithm), $password, true);
             return $alg_str.base64_encode($hash);
@@ -321,7 +382,7 @@ class Crypto
             $salt = openssl_random_pseudo_bytes($bytes);
         }
 
-        if ($algorithm[0] == 'S' && in_array(substr(strtolower($algorithm), 1), hash_algos())) {
+        if ($algorithm[0] == 'S' && in_array(substr(strtolower($algorithm), 1), hash_algos(), true)) {
             $alg = substr(strtolower($algorithm), 1); // 'sha256' etc
             $alg_str = '{'.str_replace('SSHA1', 'SSHA', $algorithm).'}'; // LDAP compatibility
             $hash = hash($alg, $password.$salt, true);
@@ -384,17 +445,16 @@ class Crypto
 
         // match algorithm string (e.g. '{SSHA256}', '{MD5}')
         if (preg_match('/^{(.*?)}(.*)$/', $hash, $matches)) {
-
             // LDAP compatibility
             $alg = preg_replace('/^(S?SHA)$/', '${1}1', $matches[1]);
 
             // hash w/o salt
-            if (in_array(strtolower($alg), hash_algos())) {
+            if (in_array(strtolower($alg), hash_algos(), true)) {
                 return self::secureCompare($hash, self::pwHash($password, $alg));
             }
 
             // hash w/ salt
-            if ($alg[0] === 'S' && in_array(substr(strtolower($alg), 1), hash_algos())) {
+            if ($alg[0] === 'S' && in_array(substr(strtolower($alg), 1), hash_algos(), true)) {
                 $php_alg = substr(strtolower($alg), 1);
 
                 // get hash length of this algorithm to learn how long the salt is
