@@ -57,19 +57,19 @@ try {
         );
     }
 
-    $adfs_service_location = SimpleSAML_Module::getModuleURL('adfs').'/idp/prp.php';
+    $adfs_service_location = SimpleSAML\Module::getModuleURL('adfs').'/idp/prp.php';
     $metaArray = array(
         'metadata-set'        => 'adfs-idp-remote',
         'entityid'            => $idpentityid,
         'SingleSignOnService' => array(
             0 => array(
-                'Binding'  => SAML2_Const::BINDING_HTTP_REDIRECT,
+                'Binding'  => \SAML2\Constants::BINDING_HTTP_REDIRECT,
                 'Location' => $adfs_service_location
             )
         ),
         'SingleLogoutService' => array(
             0 => array(
-                'Binding'  => SAML2_Const::BINDING_HTTP_REDIRECT,
+                'Binding'  => \SAML2\Constants::BINDING_HTTP_REDIRECT,
                 'Location' => $adfs_service_location
             )
         ),
@@ -148,7 +148,8 @@ try {
 
         $t->data['clipboard.js'] = true;
         $t->data['available_certs'] = $availableCerts;
-        $t->data['header'] = 'adfs-idp';
+        $t->data['header'] = 'adfs-idp'; // TODO: Replace with headerString in 2.0
+        $t->data['headerString'] = $t->noop('metadata_adfs-idp');
         $t->data['metaurl'] = \SimpleSAML\Utils\HTTP::getSelfURLNoQuery();
         $t->data['metadata'] = htmlspecialchars($metaxml);
         $t->data['metadataflat'] = htmlspecialchars($metaflat);
