@@ -2,11 +2,10 @@
 /**
  * Cookie storage for consent
  *
- * This class implements a consent store which stores the consent information
- * in cookies on the users computer.
+ * This class implements a consent store which stores the consent information in cookies on the users computer.
  *
  * Example - Consent module with cookie store:
- * 
+ *
  * <code>
  * 'authproc' => array(
  *   array(
@@ -24,15 +23,14 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
     /**
      * Check for consent.
      *
-     * This function checks whether a given user has authorized the release of
-     * the attributes identified by $attributeSet from $source to $destination.
+     * This function checks whether a given user has authorized the release of the attributes identified by
+     * $attributeSet from $source to $destination.
      *
      * @param string $userId        The hash identifying the user at an IdP.
      * @param string $destinationId A string which identifies the destination.
      * @param string $attributeSet  A hash which identifies the attributes.
      *
-     * @return bool True if the user has given consent earlier, false if not
-     *              (or on error).
+     * @return bool True if the user has given consent earlier, false if not (or on error).
      */
     public function hasConsent($userId, $destinationId, $attributeSet)
     {
@@ -44,17 +42,17 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
 
         $data = $userId . ':' . $attributeSet . ':' . $destinationId;
 
-        SimpleSAML_Logger::debug('Consent cookie - Get [' . $data . ']');
+        SimpleSAML\Logger::debug('Consent cookie - Get [' . $data . ']');
 
         if (!array_key_exists($cookieName, $_COOKIE)) {
-            SimpleSAML_Logger::debug(
+            SimpleSAML\Logger::debug(
                 'Consent cookie - no cookie with name \'' .
                 $cookieName . '\'.'
             );
             return false;
         }
         if (!is_string($_COOKIE[$cookieName])) {
-            SimpleSAML_Logger::warning(
+            SimpleSAML\Logger::warning(
                 'Value of consent cookie wasn\'t a string. Was: ' .
                 var_export($_COOKIE[$cookieName], true)
             );
@@ -64,24 +62,25 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         $data = self::_sign($data);
 
         if ($_COOKIE[$cookieName] !== $data) {
-            SimpleSAML_Logger::info(
+            SimpleSAML\Logger::info(
                 'Attribute set changed from the last time consent was given.'
             );
             return false;
         }
 
-        SimpleSAML_Logger::debug(
+        SimpleSAML\Logger::debug(
             'Consent cookie - found cookie with correct name and value.'
         );
 
         return true;
     }
 
+
     /**
      * Save consent.
      *
-     * Called when the user asks for the consent to be saved. If consent information
-     * for the given user and destination already exists, it should be overwritten.
+     * Called when the user asks for the consent to be saved. If consent information for the given user and destination
+     * already exists, it should be overwritten.
      *
      * @param string $userId        The hash identifying the user at an IdP.
      * @param string $destinationId A string which identifies the destination.
@@ -98,12 +97,13 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         $name = self::_getCookieName($userId, $destinationId);
         $value = $userId . ':' . $attributeSet . ':' . $destinationId;
 
-        SimpleSAML_Logger::debug('Consent cookie - Set [' . $value . ']');
+        SimpleSAML\Logger::debug('Consent cookie - Set [' . $value . ']');
 
         $value = self::_sign($value);
         $this->_setConsentCookie($name, $value);
     }
 
+
     /**
      * Delete consent.
      *
@@ -123,12 +123,16 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         $this->_setConsentCookie($name, null);
     }
 
+
     /**
      * Delete consent.
      *
      * @param string $userId The hash identifying the user at an IdP.
      *
-     * @return void
+     * @return void This method does not return.
+     *
+     * @throws Exception This method always throws an exception indicating that it is not possible to delete all given
+     * consents with this handler.
      */
     public function deleteAllConsents($userId)
     {
@@ -139,13 +143,14 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         );
     }
 
+
     /**
      * Retrieve consents.
      *
      * This function should return a list of consents the user has saved.
      *
      * @param string $userId The hash identifying the user at an IdP.
-     * 
+     *
      * @return array Array of all destination ids the user has given consent for.
      */
     public function getConsents($userId)
@@ -168,7 +173,7 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
 
             $tmp = explode(':', $value, 3);
             if (count($tmp) !== 3) {
-                SimpleSAML_Logger::warning(
+                SimpleSAML\Logger::warning(
                     'Consent cookie with invalid value: ' . $value
                 );
                 continue;
@@ -186,13 +191,14 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         return $ret;
     }
 
+
     /**
      * Calculate a signature of some data.
      *
      * This function calculates a signature of the data.
      *
      * @param string $data The data which should be signed.
-     * 
+     *
      * @return string The signed data.
      */
     private static function _sign($data)
@@ -204,13 +210,14 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         return sha1($secretSalt . $data . $secretSalt) . ':' . $data;
     }
 
+
     /**
      * Verify signed data.
      *
      * This function verifies signed data.
      *
      * @param string $signedData The data which is signed.
-     * 
+     *
      * @return string|false The data, or false if the signature is invalid.
      */
     private static function _verify($signedData)
@@ -219,20 +226,21 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
 
         $data = explode(':', $signedData, 2);
         if (count($data) !== 2) {
-            SimpleSAML_Logger::warning('Consent cookie: Missing signature.');
+            SimpleSAML\Logger::warning('Consent cookie: Missing signature.');
             return false;
         }
         $data = $data[1];
 
         $newSignedData = self::_sign($data);
         if ($newSignedData !== $signedData) {
-            SimpleSAML_Logger::warning('Consent cookie: Invalid signature.');
+            SimpleSAML\Logger::warning('Consent cookie: Invalid signature.');
             return false;
         }
 
         return $data;
     }
 
+
     /**
      * Get cookie name.
      *
@@ -251,12 +259,12 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         return 'sspmod_consent:' . sha1($userId . ':' . $destinationId);
     }
 
+
     /**
      * Helper function for setting a cookie.
      *
      * @param string      $name  Name of the cookie.
-     * @param string|null $value Value of the cookie. Set this to null to
-     *                           delete the cookie.
+     * @param string|null $value Value of the cookie. Set this to null to delete the cookie.
      *
      * @return void
      */
@@ -268,8 +276,8 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
         $globalConfig = SimpleSAML_Configuration::getInstance();
         $params = array(
             'lifetime' => (90*24*60*60),
-            'path' => ('/' . $globalConfig->getBaseURL()),
-            'httponly' => FALSE,
+            'path' => ($globalConfig->getBasePath()),
+            'httponly' => false,
         );
 
         if (\SimpleSAML\Utils\HTTP::isHTTPS()) {
@@ -279,7 +287,6 @@ class sspmod_consent_Consent_Store_Cookie extends sspmod_consent_Store
             $params['secure'] = false;
         }
 
-        \SimpleSAML\Utils\HTTP::setCookie($name, $value, $params, FALSE);
+        \SimpleSAML\Utils\HTTP::setCookie($name, $value, $params, false);
     }
-
 }
