@@ -21,7 +21,7 @@ session_cache_limiter('nocache');
 
 $globalConfig = SimpleSAML_Configuration::getInstance();
 
-SimpleSAML_Logger::info('Consent - getconsent: Accessing consent interface');
+SimpleSAML\Logger::info('Consent - getconsent: Accessing consent interface');
 
 if (!array_key_exists('StateId', $_REQUEST)) {
     throw new SimpleSAML_Error_BadRequest(
@@ -44,9 +44,9 @@ if (array_key_exists('core:SP', $state)) {
 // The user has pressed the yes-button
 if (array_key_exists('yes', $_REQUEST)) {
     if (array_key_exists('saveconsent', $_REQUEST)) {
-        SimpleSAML_Logger::stats('consentResponse remember');		
+        SimpleSAML\Logger::stats('consentResponse remember');
     } else {
-        SimpleSAML_Logger::stats('consentResponse rememberNot');
+        SimpleSAML\Logger::stats('consentResponse rememberNot');
     }
 
     $statsInfo = array(
@@ -67,14 +67,14 @@ if (array_key_exists('yes', $_REQUEST)) {
         $targetedId = $state['consent:store.destination'];
         $attributeSet = $state['consent:store.attributeSet'];
 
-        SimpleSAML_Logger::debug(
+        SimpleSAML\Logger::debug(
             'Consent - saveConsent() : [' . $userId . '|' .
             $targetedId . '|' .  $attributeSet . ']'
         );	
         try {
             $store->saveConsent($userId, $targetedId, $attributeSet);
         } catch (Exception $e) {
-            SimpleSAML_Logger::error('Consent: Error writing to storage: ' . $e->getMessage());
+            SimpleSAML\Logger::error('Consent: Error writing to storage: ' . $e->getMessage());
         }
     }
 
@@ -87,7 +87,7 @@ $noconsentattributes = $state['consent:noconsentattributes'];
 
 // Remove attributes that do not require consent
 foreach ($attributes AS $attrkey => $attrval) {
-    if (in_array($attrkey, $noconsentattributes)) {
+    if (in_array($attrkey, $noconsentattributes, true)) {
         unset($attributes[$attrkey]);
     }
 }
@@ -96,15 +96,15 @@ $para = array(
 );
 
 // Reorder attributes according to attributepresentation hooks
-SimpleSAML_Module::callHooks('attributepresentation', $para);
+SimpleSAML\Module::callHooks('attributepresentation', $para);
 
 // Make, populate and layout consent form
 $t = new SimpleSAML_XHTML_Template($globalConfig, 'consent:consentform.php');
 $t->data['srcMetadata'] = $state['Source'];
 $t->data['dstMetadata'] = $state['Destination'];
-$t->data['yesTarget'] = SimpleSAML_Module::getModuleURL('consent/getconsent.php');
+$t->data['yesTarget'] = SimpleSAML\Module::getModuleURL('consent/getconsent.php');
 $t->data['yesData'] = array('StateId' => $id);
-$t->data['noTarget'] = SimpleSAML_Module::getModuleURL('consent/noconsent.php');
+$t->data['noTarget'] = SimpleSAML\Module::getModuleURL('consent/noconsent.php');
 $t->data['noData'] = array('StateId' => $id);
 $t->data['attributes'] = $attributes;
 $t->data['checked'] = $state['consent:checked'];
