@@ -23,7 +23,7 @@ function core_hook_sanitycheck(&$hookinfo) {
 		$hookinfo['info'][] = '[core] In config.php technicalcontact_email is set properly';
 	}
 	
-	if (version_compare(phpversion(), '5.3', '>=')) {
+	if (version_compare(phpversion(), '5.4', '>=')) {
 		$hookinfo['info'][] = '[core] You are running a PHP version suitable for SimpleSAMLphp.';
 	} else {
 		$hookinfo['errors'][] = '[core] You are running an old PHP installation. Please check the requirements for your SimpleSAMLphp version and upgrade.';
@@ -33,12 +33,12 @@ function core_hook_sanitycheck(&$hookinfo) {
 	$mihookinfo = array(
 		'info' => &$info,
 	);
-	$availmodules = SimpleSAML_Module::getModules();
-	SimpleSAML_Module::callHooks('moduleinfo', $mihookinfo);
+	$availmodules = SimpleSAML\Module::getModules();
+	SimpleSAML\Module::callHooks('moduleinfo', $mihookinfo);
 	foreach($info AS $mi => $i) {
 		if (isset($i['dependencies']) && is_array($i['dependencies'])) {
 			foreach ($i['dependencies'] AS $dep) {
-				if (!in_array($dep, $availmodules)) {
+				if (!in_array($dep, $availmodules, true)) {
 					$hookinfo['errors'][] = '[core] Module dependency not met: ' . $mi . ' requires ' . $dep;
 				}
 			}
