@@ -6,7 +6,7 @@
  * This filter allows you to add attributes to the attribute set being processed.
  *
  * @author Olav Morken, UNINETT AS.
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_core_Auth_Process_AttributeAdd extends SimpleSAML_Auth_ProcessingFilter {
 
@@ -45,10 +45,6 @@ class sspmod_core_Auth_Process_AttributeAdd extends SimpleSAML_Auth_ProcessingFi
 				continue;
 			}
 
-			if(!is_string($name)) {
-				throw new Exception('Invalid attribute name: ' . var_export($name, TRUE));
-			}
-
 			if(!is_array($values)) {
 				$values = array($values);
 			}
@@ -87,5 +83,3 @@ class sspmod_core_Auth_Process_AttributeAdd extends SimpleSAML_Auth_ProcessingFi
 	}
 
 }
-
-?>
\ No newline at end of file
