@@ -44,18 +44,18 @@ class sspmod_core_Auth_Process_LanguageAdaptor extends SimpleSAML_Auth_Processin
 		if (array_key_exists($this->langattr, $attributes))
 			$attrlang = $attributes[$this->langattr][0];
 
-		$lang = SimpleSAML_XHTML_Template::getLanguageCookie();
+		$lang = SimpleSAML\Locale\Language::getLanguageCookie();
 
 
 		if (isset($attrlang))
-			SimpleSAML_Logger::debug('LanguageAdaptor: Language in attribute was set [' . $attrlang . ']');
+			SimpleSAML\Logger::debug('LanguageAdaptor: Language in attribute was set [' . $attrlang . ']');
 		if (isset($lang))
-			SimpleSAML_Logger::debug('LanguageAdaptor: Language in session   was set [' . $lang . ']');
+			SimpleSAML\Logger::debug('LanguageAdaptor: Language in session   was set [' . $lang . ']');
 
 
 		if (isset($attrlang) && !isset($lang)) {
 			// Language set in attribute but not in cookie - update cookie
-			SimpleSAML_XHTML_Template::setLanguageCookie($attrlang);
+			SimpleSAML\Locale\Language::setLanguageCookie($attrlang);
 		} elseif (!isset($attrlang) && isset($lang)) {
 			// Language set in cookie, but not in attribute. Update attribute
 			$request['Attributes'][$this->langattr] = array($lang);
