@@ -76,11 +76,11 @@ class sspmod_core_Auth_Process_ScopeFromAttribute extends SimpleSAML_Auth_Proces
 			$attributes[$this->targetAttribute] = array();
 			$scope = substr($sourceAttrVal, $scopeIndex+1);
 			$attributes[$this->targetAttribute][] = $scope;
-			SimpleSAML_Logger::debug('ScopeFromAttribute: Inserted new attribute ' .
+			SimpleSAML\Logger::debug('ScopeFromAttribute: Inserted new attribute ' .
 			                         $this->targetAttribute . ', with scope ' .
 			                         $scope);
 		} else {
-			SimpleSAML_Logger::warning('ScopeFromAttribute: The configured source attribute ' .
+			SimpleSAML\Logger::warning('ScopeFromAttribute: The configured source attribute ' .
 			                           $this->sourceAttribute .
 			                           ' does not have a scope. Did not add attribute ' .
 			                           $this->targetAttribute . '.');
