@@ -39,13 +39,13 @@ class sspmod_core_Auth_Process_WarnShortSSOInterval extends SimpleSAML_Auth_Proc
 			$entityId = 'UNKNOWN';
 		}
 
-		SimpleSAML_Logger::warning('WarnShortSSOInterval: Only ' . $timeDelta .
+		SimpleSAML\Logger::warning('WarnShortSSOInterval: Only ' . $timeDelta .
 			' seconds since last SSO for this user from the SP ' .
 			var_export($entityId, TRUE));
 
 		// Save state and redirect
 		$id = SimpleSAML_Auth_State::saveState($state, 'core:short_sso_interval');
-		$url = SimpleSAML_Module::getModuleURL('core/short_sso_interval.php');
+		$url = SimpleSAML\Module::getModuleURL('core/short_sso_interval.php');
 		\SimpleSAML\Utils\HTTP::redirectTrustedURL($url, array('StateId' => $id));
 	}
 
