@@ -31,4 +31,4 @@ if ($this->data['isadmin']) {
 	
 
 		
-<?php $this->includeAtTemplateBase('includes/footer.php'); ?>
\ No newline at end of file
+<?php $this->includeAtTemplateBase('includes/footer.php');
