@@ -14,5 +14,5 @@ if (!isset($_REQUEST['AuthId']) || !is_string($_REQUEST['AuthId'])) {
 	throw new SimpleSAML_Error_BadRequest('Missing AuthId parameter.');
 }
 
-$as = new SimpleSAML_Auth_Simple($_REQUEST['AuthId']);
+$as = new \SimpleSAML\Auth\Simple($_REQUEST['AuthId']);
 $as->logout(\SimpleSAML\Utils\HTTP::checkURLAllowed($_REQUEST['ReturnTo']));
