@@ -3,7 +3,7 @@
 /**
  * This page provides a way to create a redirect to a POST request.
  *
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 
 if (array_key_exists('RedirId', $_REQUEST)) {
@@ -16,7 +16,7 @@ if (array_key_exists('RedirId', $_REQUEST)) {
 		throw new SimpleSAML_Error_BadRequest('Invalid RedirInfo data.');
 	}
 
-	list($sessionId, $postId) = explode(':', SimpleSAML_Utilities::aesDecrypt($encData));
+	list($sessionId, $postId) = explode(':', SimpleSAML\Utils\Crypto::aesDecrypt($encData));
 
 	if (empty($sessionId) || empty($postId)) {
 		throw new SimpleSAML_Error_BadRequest('Invalid session info data.');
@@ -34,7 +34,7 @@ if ($session === NULL) {
 $postData = $session->getData('core_postdatalink', $postId);
 
 if ($postData === NULL) {
-	/* The post data is missing, probably because it timed out. */
+	// The post data is missing, probably because it timed out
 	throw new Exception('The POST data we should restore was lost.');
 }
 
@@ -45,10 +45,8 @@ assert('array_key_exists("url", $postData)');
 assert('array_key_exists("post", $postData)');
 
 $config = SimpleSAML_Configuration::getInstance();
-$p = new SimpleSAML_XHTML_Template($config, 'post.php');
-$p->data['destination'] = $postData['url'];
-$p->data['post'] = $postData['post'];
-$p->show();
+$template = new SimpleSAML_XHTML_Template($config, 'post.php');
+$template->data['destination'] = $postData['url'];
+$template->data['post'] = $postData['post'];
+$template->show();
 exit(0);
-
-?>
\ No newline at end of file
