@@ -9,7 +9,7 @@ function cron_hook_frontpage(&$links) {
 	assert('array_key_exists("links", $links)');
 
 	$links['config'][] = array(
-		'href' => SimpleSAML_Module::getModuleURL('cron/croninfo.php'),
+		'href' => SimpleSAML\Module::getModuleURL('cron/croninfo.php'),
 		'text' => array('en' => 'Cron module information page'),
 	);
 
