@@ -126,19 +126,19 @@ class sspmod_expirycheck_Auth_Process_ExpiryDate extends SimpleSAML_Auth_Process
 				return;
 			}
 
-			SimpleSAML_Logger::warning('expirycheck: NetID ' . $netId .
+			SimpleSAML\Logger::warning('expirycheck: NetID ' . $netId .
 			                           ' is about to expire!');
 
 			// Save state and redirect
 			$state['expireOnDate'] = date($this->date_format, $expireOnDate);
 			$state['netId'] = $netId;
 			$id = SimpleSAML_Auth_State::saveState($state, 'expirywarning:about2expire');
-			$url = SimpleSAML_Module::getModuleURL('expirycheck/about2expire.php');
+			$url = SimpleSAML\Module::getModuleURL('expirycheck/about2expire.php');
 			\SimpleSAML\Utils\HTTP::redirectTrustedURL($url, array('StateId' => $id));
 		}
 
 		if (!self::checkDate($expireOnDate)) {
-			SimpleSAML_Logger::error('expirycheck: NetID ' . $netId .
+			SimpleSAML\Logger::error('expirycheck: NetID ' . $netId .
 				' has expired [' . date($this->date_format, $expireOnDate) . ']. Access denied!');
 			$globalConfig = SimpleSAML_Configuration::getInstance();
 
@@ -146,7 +146,7 @@ class sspmod_expirycheck_Auth_Process_ExpiryDate extends SimpleSAML_Auth_Process
 			$state['expireOnDate'] = date($this->date_format, $expireOnDate);
 			$state['netId'] = $netId;
 			$id = SimpleSAML_Auth_State::saveState($state, 'expirywarning:expired');
-			$url = SimpleSAML_Module::getModuleURL('expirycheck/expired.php');
+			$url = SimpleSAML\Module::getModuleURL('expirycheck/expired.php');
 			\SimpleSAML\Utils\HTTP::redirectTrustedURL($url, array('StateId' => $id));
 
 		}
