@@ -6,7 +6,7 @@
  * @package SimpleSAMLphp
  */
 
-SimpleSAML_Logger::info('expirycheck - User has been warned that NetID is near to expirational date.');
+SimpleSAML\Logger::info('expirycheck - User has been warned that NetID is near to expirational date.');
 
 if (!array_key_exists('StateId', $_REQUEST)) {
 	throw new SimpleSAML_Error_BadRequest('Missing required StateId query parameter.');
