@@ -112,8 +112,10 @@ $rowTitles = array(
     'cas_badval' => $t->noop('{memcacheMonitor:memcachestat:cas_badval}'),
     'cas_hits' => $t->noop('{memcacheMonitor:memcachestat:cas_hits}'),
     'cas_misses' => $t->noop('{memcacheMonitor:memcachestat:cas_misses}'),
+    'cmd_flush' => $t->noop('{memcacheMonitor:memcachestat:cmd_flush}'),
     'cmd_get' => $t->noop('{memcacheMonitor:memcachestat:cmd_get}'),
     'cmd_set' => $t->noop('{memcacheMonitor:memcachestat:cmd_set}'),
+    'cmd_touch' => $t->noop('{memcacheMonitor:memcachestat:cmd_touch}'),
     'connection_structures' => $t->noop('{memcacheMonitor:memcachestat:connection_structures}'),
     'conn_yields' => $t->noop('{memcacheMonitor:memcachestat:conn_yields}'),
     'curr_connections' => $t->noop('{memcacheMonitor:memcachestat:curr_connections}'),
@@ -122,21 +124,31 @@ $rowTitles = array(
     'decr_misses' => $t->noop('{memcacheMonitor:memcachestat:decr_misses}'),
     'delete_hits' => $t->noop('{memcacheMonitor:memcachestat:delete_hits}'),
     'delete_misses' => $t->noop('{memcacheMonitor:memcachestat:delete_misses}'),
+    'expired_unfetched' => $t->noop('{memcacheMonitor:memcachestat:expired_unfetched}'),
+    'evicted_unfetched' => $t->noop('{memcacheMonitor:memcachestat:evicted_unfetched}'),
     'evictions' => $t->noop('{memcacheMonitor:memcachestat:evictions}'),
     'get_hits' => $t->noop('{memcacheMonitor:memcachestat:get_hits}'),
     'get_misses' => $t->noop('{memcacheMonitor:memcachestat:get_misses}'),
+    'hash_bytes' => $t->noop('{memcacheMonitor:memcachestat:hash_bytes}'),
+    'hash_is_expanding' => $t->noop('{memcacheMonitor:memcachestat:hash_is_expanding}'),
+    'hash_power_level' => $t->noop('{memcacheMonitor:memcachestat:hash_power_level}'),
     'incr_hits' => $t->noop('{memcacheMonitor:memcachestat:incr_hits}'),
     'incr_misses' => $t->noop('{memcacheMonitor:memcachestat:incr_misses}'),
+    'libevent' => $t->noop('{memcacheMonitor:memcachestat:libevent}'),
     'limit_maxbytes' => $t->noop('{memcacheMonitor:memcachestat:limit_maxbytes}'),
     'listen_disabled_num' => $t->noop('{memcacheMonitor:memcachestat:listen_disabled_num}'),
     'pid' => $t->noop('{memcacheMonitor:memcachestat:pid}'),
     'pointer_size' => $t->noop('{memcacheMonitor:memcachestat:pointer_size}'),
+    'reclaimed' => $t->noop('{memcacheMonitor:memcachestat:reclaimed}'),
+    'reserved_fds' => $t->noop('{memcacheMonitor:memcachestat:reserved_fds}'),
     'rusage_system' => $t->noop('{memcacheMonitor:memcachestat:rusage_system}'),
     'rusage_user' => $t->noop('{memcacheMonitor:memcachestat:rusage_user}'),
     'threads' => $t->noop('{memcacheMonitor:memcachestat:threads}'),
     'time' => $t->noop('{memcacheMonitor:memcachestat:time}'),
     'total_connections' => $t->noop('{memcacheMonitor:memcachestat:total_connections}'),
     'total_items' => $t->noop('{memcacheMonitor:memcachestat:total_items}'),
+    'touch_hits' => $t->noop('{memcacheMonitor:memcachestat:touch_hits}'),
+    'touch_misses' => $t->noop('{memcacheMonitor:memcachestat:touch_misses}'),
     'uptime' => $t->noop('{memcacheMonitor:memcachestat:uptime}'),
     'version' => $t->noop('{memcacheMonitor:memcachestat:version}'),
 );
