@@ -10,10 +10,7 @@
 $this->includeAtTemplateBase('includes/header.php');
 ?>
 <h1><?php echo $this->t('{negotiate:negotiate:disable_title}'); ?></h1>
-<?php
-$url = SimpleSAML_Module::getModuleURL('negotiate/enable.php');
-?>
-<?php echo $this->t('{negotiate:negotiate:disable_info_pre}', array('URL' => htmlspecialchars($url))); ?>
+<?php echo $this->t('{negotiate:negotiate:disable_info_pre}', array('URL' => htmlspecialchars($this->data['url']))); ?>
 
 <?php echo $this->t('{negotiate:negotiate:info_post}'); ?>
 
