@@ -12,7 +12,7 @@ function portal_hook_htmlinject(&$hookinfo) {
 	assert('array_key_exists("page", $hookinfo)');
 
 	$links = array('links' => array());
-	SimpleSAML_Module::callHooks('frontpage', $links);
+	SimpleSAML\Module::callHooks('frontpage', $links);
 
 	$portalConfig = SimpleSAML_Configuration::getOptionalConfig('module_portal.php');
 	
@@ -24,7 +24,7 @@ function portal_hook_htmlinject(&$hookinfo) {
 	$pagesets = $portalConfig->getValue('pagesets', array(
 		array('frontpage_welcome', 'frontpage_config', 'frontpage_auth', 'frontpage_federation'),
 	));
-	SimpleSAML_Module::callHooks('portalextras', $pagesets);
+	SimpleSAML\Module::callHooks('portalextras', $pagesets);
 	$portal = new sspmod_portal_Portal($allLinks, $pagesets);
 	
 	if (!$portal->isPortalized($hookinfo['page'])) return;
