@@ -87,26 +87,27 @@ abstract class sspmod_saml_BaseNameIDGenerator extends SimpleSAML_Auth_Processin
 			return;
 		}
 
-		$nameId = array('Value' => $value);
+		$nameId = new \SAML2\XML\saml\NameID();
+		$nameId->value = $value;
 
 		if ($this->nameQualifier === TRUE) {
 			if (isset($state['IdPMetadata']['entityid'])) {
-				$nameId['NameQualifier'] = $state['IdPMetadata']['entityid'];
+				$nameId->NameQualifier = $state['IdPMetadata']['entityid'];
 			} else {
-				SimpleSAML_Logger::warning('No IdP entity ID, unable to set NameQualifier.');
+				SimpleSAML\Logger::warning('No IdP entity ID, unable to set NameQualifier.');
 			}
 		} elseif (is_string($this->nameQualifier)) {
-			$nameId['NameQualifier'] = $this->nameQualifier;
+			$nameId->NameQualifier = $this->nameQualifier;
 		}
 
 		if ($this->spNameQualifier === TRUE) {
 			if (isset($state['SPMetadata']['entityid'])) {
-				$nameId['SPNameQualifier'] = $state['SPMetadata']['entityid'];
+				$nameId->SPNameQualifier = $state['SPMetadata']['entityid'];
 			} else {
-				SimpleSAML_Logger::warning('No SP entity ID, unable to set SPNameQualifier.');
+				SimpleSAML\Logger::warning('No SP entity ID, unable to set SPNameQualifier.');
 			}
 		} elseif (is_string($this->spNameQualifier)) {
-			$nameId['SPNameQualifier'] = $this->spNameQualifier;
+			$nameId->SPNameQualifier = $this->spNameQualifier;
 		}
 
 		$state['saml:NameID'][$this->format] = $nameId;
