@@ -7,7 +7,6 @@
  */
 class sspmod_statistics_StatDataset
 {
-
     protected $statconfig;
     protected $ruleconfig;
     protected $timeresconfig;
@@ -55,19 +54,16 @@ class sspmod_statistics_StatDataset
         $this->loadData();
     }
 
-
     public function getFileSlot()
     {
         return $this->fileslot;
     }
 
-
     public function getTimeRes()
     {
         return $this->timeres;
     }
 
-
     public function setDelimiter($delimiter = '_')
     {
         if (empty($delimiter)) {
@@ -76,7 +72,6 @@ class sspmod_statistics_StatDataset
         $this->delimiter = $delimiter;
     }
 
-
     public function getDelimiter()
     {
         if ($this->delimiter === '_') {
@@ -85,7 +80,6 @@ class sspmod_statistics_StatDataset
         return $this->delimiter;
     }
 
-
     public function calculateMax()
     {
         $maxvalue = 0;
@@ -98,7 +92,6 @@ class sspmod_statistics_StatDataset
         $this->max = sspmod_statistics_Graph_GoogleCharts::roof($maxvalue);
     }
 
-
     public function getDebugData()
     {
         $debugdata = array();
@@ -115,7 +108,6 @@ class sspmod_statistics_StatDataset
         return $debugdata;
     }
 
-
     public function aggregateSummary()
     {
         // aggregate summary table from dataset. To be used in the table view
@@ -133,7 +125,6 @@ class sspmod_statistics_StatDataset
         $this->summary = array_reverse($this->summary, true);
     }
 
-
     public function getTopDelimiters()
     {
         // create a list of delimiter keys that has the highest total summary in this period
@@ -151,7 +142,6 @@ class sspmod_statistics_StatDataset
         return $topdelimiters;
     }
 
-
     public function availDelimiters()
     {
         $availDelimiters = array();
@@ -161,7 +151,6 @@ class sspmod_statistics_StatDataset
         return array_keys($availDelimiters);
     }
 
-
     public function getPieData()
     {
         $piedata = array();
@@ -176,25 +165,21 @@ class sspmod_statistics_StatDataset
         return $piedata;
     }
 
-
     public function getMax()
     {
         return $this->max;
     }
 
-
     public function getSummary()
     {
         return $this->summary;
     }
 
-
     public function getResults()
     {
         return $this->results;
     }
 
-
     public function getAxis()
     {
         $slotsize = $this->timeresconfig->getValue('slot');
@@ -223,7 +208,6 @@ class sspmod_statistics_StatDataset
         return array('axis' => $axis, 'axispos' => $axispos);
     }
 
-
     /*
      * Walk through dataset to get percent values from max into dataset[].
      */
@@ -247,18 +231,17 @@ class sspmod_statistics_StatDataset
         return $dataset;
     }
 
-
     public function getDelimiterPresentation()
     {
         $config = SimpleSAML_Configuration::getInstance();
-        $t = new SimpleSAML_XHTML_Template($config, 'statistics:statistics-tpl.php');
+        $t = new SimpleSAML_XHTML_Template($config, 'statistics:statistics.tpl.php');
 
         $availdelimiters = $this->availDelimiters();
 
         // create a delimiter presentation filter for this rule...
         if ($this->ruleconfig->hasValue('fieldPresentation')) {
             $fieldpresConfig = $this->ruleconfig->getConfigItem('fieldPresentation');
-            $classname = SimpleSAML_Module::resolveClass(
+            $classname = SimpleSAML\Module::resolveClass(
                 $fieldpresConfig->getValue('class'),
                 'Statistics_FieldPresentation'
             );
@@ -273,7 +256,6 @@ class sspmod_statistics_StatDataset
         return array();
     }
 
-
     public function getDelimiterPresentationPie()
     {
         $topdelimiters = $this->getTopDelimiters();
@@ -291,7 +273,6 @@ class sspmod_statistics_StatDataset
         return $pieaxis;
     }
 
-
     public function loadData()
     {
         $statdir = $this->statconfig->getValue('statdir');
